@@ -35,9 +35,9 @@ void AlkDomTest::testCreateDocument()
     doc.appendChild(el);
 
     QCOMPARE(doc.toString(false),
-             "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<!-- comment for 'Tag' element -->\n<Tag key=\"value\">\n<!--\n    comment for 'SubTag' element\n    "
-             "second line comment\n-->\n<SubTag subkey=\"value\" />\n</Tag>\n");
+             QLatin1String("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<!-- comment for 'Tag' element -->\n<Tag key=\"value\">\n<!--\n    comment for 'SubTag' element\n    "
+             "second line comment\n-->\n<SubTag subkey=\"value\" />\n</Tag>\n"));
     QCOMPARE(doc.toString(true),
-             "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n <!-- comment for 'Tag' element -->\n <Tag key=\"value\">\n"
-             "  <!--\n      comment for 'SubTag' element\n      second line comment\n  -->\n  <SubTag subkey=\"value\" />\n </Tag>\n");
+             QLatin1String("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n <!-- comment for 'Tag' element -->\n <Tag key=\"value\">\n"
+             "  <!--\n      comment for 'SubTag' element\n      second line comment\n  -->\n  <SubTag subkey=\"value\" />\n </Tag>\n"));
 }
