@@ -9,6 +9,7 @@
 
 #include "alkonlinequotetest.h"
 
+#include "alkdebug.h"
 #include "alkonlinequote.h"
 #include "alkonlinequotesprofile.h"
 #include "alkquotereceiver.h"
@@ -123,7 +124,8 @@ void AlkOnlineQuoteTest::testAlkOnlineQuoteErrorCopy()
 
 void AlkOnlineQuoteTest::init()
 {
-    m_profile = new AlkOnlineQuotesProfile("alkimia");
+    // TODO The used test profile should be readonly to prevent any changes by the ui
+    m_profile = new AlkOnlineQuotesProfile("Test", AlkOnlineQuotesProfile::Type::Test);
 }
 
 void AlkOnlineQuoteTest::cleanup()
@@ -134,32 +136,46 @@ void AlkOnlineQuoteTest::cleanup()
 void AlkOnlineQuoteTest::testQuoteSources()
 {
     QStringList sources = m_profile->quoteSources();
-    qDebug() << sources;
+    alkDebug() << sources;
     QVERIFY(sources.size() > 0);
 }
 
 void AlkOnlineQuoteTest::testLaunch()
 {
     AlkOnlineQuote quote(m_profile);
+    quote.setTimeout(20000);
     convertertest::AlkQuoteReceiver receiver(&quote);
     receiver.setVerbose(true);
 
-    for (const QString &source : m_profile->quoteSources())
-        if (!source.endsWith(QLatin1String(".webkit")))
-            QVERIFY(quote.launch("EUR USD", "EUR USD", source));
+    for (const QString &name : m_profile->quoteSources()) {
+        AlkOnlineQuoteSource source(name, m_profile);
+        if (source.downloadType() == AlkOnlineQuoteSource::Default) {
+            if (source.requiresTwoIdentifier())
+                QVERIFY(quote.launch("EUR USD", "EUR USD", name));
+            else
+                QVERIFY(quote.launch("EUR", "EUR", name));
+        }
+    }
 }
 
-void AlkOnlineQuoteTest::testLaunchWithBrowser()
+void AlkOnlineQuoteTest::testLaunchWithJavaScriptSupport()
 {
 #if defined(BUILD_WITH_WEBKIT) || defined(BUILD_WITH_WEBENGINE)
     AlkOnlineQuote quote(m_profile);
+    quote.setTimeout(20000);
     convertertest::AlkQuoteReceiver receiver(&quote);
     receiver.setVerbose(true);
 
-    for (const QString &source : m_profile->quoteSources())
-        if (source.endsWith(QLatin1String(".webkit")))
-            QVERIFY(quote.launch("EUR USD", "EUR USD", source));
+    for (const QString &name : m_profile->quoteSources()) {
+        AlkOnlineQuoteSource source(name, m_profile);
+        if (source.downloadType() == AlkOnlineQuoteSource::Javascript) {
+            if (source.requiresTwoIdentifier())
+                QVERIFY(quote.launch("EUR USD", "EUR USD", name));
+            else
+                QVERIFY(quote.launch("EUR", "EUR", name));
+        }
+    }
 #else
-    QSKIP("Brower based tests skipped because requirements are not met", SkipAll);
+    QSKIP("Browser based tests skipped because requirements are not met", SkipAll);
 #endif
 }
