@@ -17,7 +17,7 @@ class AlkQuoteItemTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
 
     void init();
     void cleanup();
