@@ -9,19 +9,15 @@
 
 #include "alkdateformat.h"
 
-#include <QDebug>
-
-
-#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
-#include <KGlobal>
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 #include <KCalendarSystem>
+#include <KGlobal>
+#include <QRegExp>
 #else
 #include <QLocale>
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
 #endif
-#include <QRegExp>
-
 
 class AlkDateFormat::Private
 {
@@ -66,16 +62,18 @@ public:
     {
         QDate date;
         if (m_format == "UNIX") {
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
-            date = QDateTime::fromSecsSinceEpoch(_in.toUInt(), Qt::UTC).date();
-#else
-            date = QDateTime::fromTime_t(_in.toUInt()).date();
-#endif
+            bool ok;
+            const quint64 unixTime = _in.toUInt(&ok);
+            if (ok) {
+                date = QDateTime::fromMSecsSinceEpoch(unixTime * 1000).date();
+            }
+
         } else {
             const QString skroogeFormat = m_format;
 
             m_format = m_format.toLower();
 
+#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
             QRegExp formatrex("([mdy]+)(\\W+)([mdy]+)(\\W+)([mdy]+)", Qt::CaseInsensitive);
             if (formatrex.indexIn(m_format) == -1) {
                 return setError(AlkDateFormat::InvalidFormatString, m_format);
@@ -88,7 +86,22 @@ public:
             m_format.append(formatrex.cap(4));
             m_format.append(QLatin1String("%"));
             m_format.append(formatrex.cap(5));
+#else
+            static QRegularExpression formatrex("([mdy]+)(\\W+)([mdy]+)(\\W+)([mdy]+)", QRegularExpression::CaseInsensitiveOption);
+            auto match = formatrex.match(m_format);
+            if (!match.hasMatch()) {
+                return setError(AlkDateFormat::InvalidFormatString, m_format);
+            }
 
+            m_format = QLatin1String("%");
+            m_format += match.captured(1);
+            m_format += match.captured(2);
+            m_format.append(QLatin1String("%"));
+            m_format += match.captured(3);
+            m_format += match.captured(4);
+            m_format.append(QLatin1String("%"));
+            m_format += match.captured(5);
+#endif
             date = convertStringKMyMoney(_in, true, 2000);
             m_format = skroogeFormat;
         }
@@ -100,11 +113,27 @@ public:
         return date;
     }
 
+    QDate convertStringUnix(const QString& _in)
+    {
+        bool ok;
+        quint64 unixTime = _in.toUInt(&ok);
+        if (!ok) {
+            return setError(AlkDateFormat::InvalidDate, _in);
+        }
+        if (m_format.startsWith(QLatin1String("%ud"))) {
+            unixTime *= 86400; // times seconds per day
+        }
+        return QDateTime::fromMSecsSinceEpoch(unixTime * 1000).date();
+    }
 
-#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 
     QDate convertStringKMyMoney(const QString &_in, bool _strict, unsigned _centurymidpoint)
     {
+        if (m_format.startsWith(QLatin1String("%u"))) {
+            return convertStringUnix(_in);
+        }
+
         //
         // Break date format string into component parts
         //
@@ -250,6 +279,10 @@ public:
 
     QDate convertStringKMyMoney(const QString& _in, bool _strict, unsigned _centurymidpoint)
     {
+      if (m_format.startsWith(QLatin1String("%u"))) {
+        return convertStringUnix(_in);
+      }
+
       //
       // Break date format string into component parts
       //
@@ -447,7 +480,6 @@ QString AlkDateFormat::lastErrorMessage() const
     return d->m_errorMessage;
 }
 
-
 QDate AlkDateFormat::convertString(const QString& date, bool strict, unsigned int centuryMidPoint)
 {
     // reset any pending errors from previous runs
