@@ -12,7 +12,6 @@
 #include "alkexception.h"
 
 #include <QDate>
-#include <QRegExp>
 #include <QString>
 #include <QStringList>
 
@@ -29,6 +28,7 @@ class ALK_NO_EXPORT AlkDateFormat
 {
 public:
     explicit AlkDateFormat(const QString &format);
+    AlkDateFormat(const AlkDateFormat& right);
     ~AlkDateFormat();
 
     AlkDateFormat& operator=(const AlkDateFormat&);
