@@ -36,6 +36,21 @@ bool AlkOnlineQuote::Errors::operator &(Type t) const
     return m_type.contains(t);
 }
 
+bool AlkOnlineQuote::Errors::operator ==(Type t) const
+{
+    return m_type.size() == 1 && m_type.contains(t);
+}
+
+bool AlkOnlineQuote::Errors::operator !=(Type t) const
+{
+    return m_type.size() != 1 || !m_type.contains(t);
+}
+
+bool AlkOnlineQuote::Errors::isEmpty() const
+{
+    return m_type.size() == 0;
+}
+
 AlkOnlineQuote::AlkOnlineQuote(AlkOnlineQuotesProfile *profile, QObject *_parent)
     : QObject(_parent)
     , d(new Private(this))
@@ -118,6 +133,16 @@ bool AlkOnlineQuote::useSingleQuoteSignal()
     return d->m_useSingleQuoteSignal;
 }
 
+bool AlkOnlineQuote::enableReverseLaunch()
+{
+    return d->m_reverseLaunchEnabled;
+}
+
+void AlkOnlineQuote::setEnableReverseLaunch(bool state)
+{
+    d->m_reverseLaunchEnabled = state;
+}
+
 const AlkOnlineQuoteSource &AlkOnlineQuote::source() const
 {
     return d->m_source;
@@ -125,21 +150,7 @@ const AlkOnlineQuoteSource &AlkOnlineQuote::source() const
 
 bool AlkOnlineQuote::launch(const QString &_symbol, const QString &_id, const QString &_source)
 {
-#ifdef ENABLE_FINANCEQUOTE
-    if (AlkOnlineQuoteSource::isFinanceQuote(_source) ||
-            d->m_profile->type() == AlkOnlineQuotesProfile::Type::Script) {
-        return d->launchFinanceQuote(_symbol, _id, _source);
-    } else
-#endif
-    d->initSource(_source);
-
-    if (d->m_source.downloadType() == AlkOnlineQuoteSource::Javascript) {
-        return d->launchWithJavaScriptSupport(_symbol, _id, AlkDownloadEngine::JavaScriptEngine);
-    } else if (d->m_source.dataFormat() == AlkOnlineQuoteSource::CSS) {
-        return d->launchWithJavaScriptSupport(_symbol, _id, AlkDownloadEngine::JavaScriptEngineCSS);
-    } else {
-        return d->launchNative(_symbol, _id);
-    }
+    return d->launch(_symbol, _id, _source);
 }
 
 const AlkOnlineQuote::Errors &AlkOnlineQuote::errors()
