@@ -24,9 +24,7 @@
 #else
 #include <KUrl>
 #endif
-#ifdef BUILD_WITH_QTNETWORK
 class QNetworkReply;
-#endif
 
 #include <QApplication>
 #include <QByteArray>
@@ -96,6 +94,25 @@ public:
     bool processDownloadedPage(const KUrl &url, const QByteArray &page);
     bool processLocalScript(const KUrl& url);
 
+    /**
+     * Return of a subtree within the tree passed with \p data based on a hierarchy specification with \p path
+     * The hierarchy of the specified tree can consist of instances of QVariantMap or QVariantList, which are
+     * identified via corresponding parts of the path specified with \o path, with a key for QVariantMap
+     * and an index for QVariantList. If no index is specified, the first entry is used.
+     * See the examples for a hierachy setup as:
+     *  \code{.cpp}
+     *     QVariantMap["key1"]->QVariantMap["key2"]->QVariantMap["key3"]  -> path = "key1:key2:key3"
+     *     QVariantMap["key1"]->QVariantList[n]->QVariantMap["key2"] -> path = "key1:<0..n-1>:key2" or "key1:key2" for the use of the first entry for compatibility reasons
+     *  \endcode
+     * @param data tree to be scanned
+     * @param path hierarchy to be searched for in the form “<key>[:<key>]...” or “<key>[:<index>][:<key>]”
+     * @param resultData return variable for the sub-tree found
+     * @param errorKey return variable for the actual processed key in the event of an error
+     * @return true - success, the path has been found and the associated sub-tree returned
+     * @return false - error when searching for the specified path
+     */
+    static bool getSubTree(const QVariantMap &data, const QString &path, QVariant &resultData, QString &errorKey);
+
 public Q_SLOTS:
     void slotLoadError(const QUrl &, const QString &);
     void slotLoadFinished(const QUrl &url, const QString &data);
