@@ -9,10 +9,11 @@
 #include "alkonlinequotesprofilemanager.h"
 #include "alkonlinequotesprofile.h"
 #include "alkwebpage.h"
+#include "alkwebview.h"
 
 #include <QPointer>
 
-#if QT_VERSION > QT_VERSION_CHECK(5,0,0)
+#if QT_VERSION > QT_VERSION_CHECK(5, 0, 0)
 #include <QLocale>
 #define initLocale() QLocale()
 #else
@@ -24,16 +25,19 @@ class AlkOnlineQuotesProfileManager::Private
 {
 public:
     AlkOnlineQuotesProfileList m_profiles;
+    QPointer<AlkWebView> m_view;
     QPointer<AlkWebPage> m_page;
-    bool m_withPage;
+    bool m_withView;
     Private()
-      : m_withPage(false)
+      : m_withView(false)
     {
     }
 
     ~Private()
     {
-        m_page.data()->deleteLater();
+        if (m_view.data()) {
+            m_view.data()->deleteLater();
+        }
     }
 };
 
@@ -47,14 +51,14 @@ AlkOnlineQuotesProfileManager::~AlkOnlineQuotesProfileManager()
     delete d;
 }
 
-bool AlkOnlineQuotesProfileManager::webPageEnabled()
+bool AlkOnlineQuotesProfileManager::webViewEnabled()
 {
-    return d->m_withPage;
+    return d->m_withView;
 }
 
-void AlkOnlineQuotesProfileManager::setWebPageEnabled(bool enable)
+void AlkOnlineQuotesProfileManager::setWebViewEnabled(bool enable)
 {
-    d->m_withPage = enable;
+    d->m_withView = enable;
 }
 
 void AlkOnlineQuotesProfileManager::addProfile(AlkOnlineQuotesProfile *profile)
@@ -90,16 +94,26 @@ QStringList AlkOnlineQuotesProfileManager::profileNames()
     return profiles;
 }
 
+void AlkOnlineQuotesProfileManager::setWebPage(AlkWebPage *webPage)
+{
+    d->m_page = webPage;
+}
+
 AlkWebPage *AlkOnlineQuotesProfileManager::webPage()
 {
-    if (!d->m_page) {
-    // make sure that translations are installed on windows
-        initLocale();
-        d->m_page = new AlkWebPage;
-    }
     return d->m_page;
 }
 
+void AlkOnlineQuotesProfileManager::setWebView(AlkWebView *webView)
+{
+    d->m_view = webView;
+}
+
+AlkWebView *AlkOnlineQuotesProfileManager::webView()
+{
+    return d->m_view;
+}
+
 AlkOnlineQuotesProfileManager &AlkOnlineQuotesProfileManager::instance()
 {
     static AlkOnlineQuotesProfileManager manager;
