@@ -94,6 +94,7 @@ public:
 #endif
     AlkOnlineQuotesModel *m_model;
     AlkOnlineQuotesWidget *m_p;
+    AlkOnlineQuote m_quote;
 
     Private(bool showProfiles, bool showUpload, AlkOnlineQuotesWidget *parent);
     ~Private();
@@ -248,6 +249,20 @@ AlkOnlineQuotesWidget::Private::Private(bool showProfiles, bool showUpload, AlkO
     connect(m_editDate, SIGNAL(textChanged(QString)), this, SLOT(slotEntryChanged()));
     connect(m_editDateFormat, SIGNAL(textChanged(QString)), this, SLOT(slotEntryChanged()));
     connect(m_editDefaultId, SIGNAL(textChanged(QString)), this, SLOT(slotEntryChanged()));
+
+    // TODO
+    // During the string freeze, these combo box entries cannot be moved from the UI file.
+    // However, to ensure that the list box entries are always defined in the source code,
+    // this should be done afterwards.
+#if 1
+    m_editPriceDecimalSeparator->setItemData(0, AlkOnlineQuoteSource::DecimalSeparator::Period);
+    m_editPriceDecimalSeparator->setItemData(1, AlkOnlineQuoteSource::DecimalSeparator::Comma);
+    m_editPriceDecimalSeparator->setItemData(2, AlkOnlineQuoteSource::DecimalSeparator::Legacy);
+#else
+    // m_editPriceDecimalSeparator->addItem(i18nc("@item:inlistbox Stock", "Legacy"), AlkOnlineQuoteSource::DecimalSeparator::Legacy);
+    // m_editPriceDecimalSeparator->addItem(i18nc("@item:inlistbox Stock", "Period (.)"), AlkOnlineQuoteSource::DecimalSeparator::Period);
+    // m_editPriceDecimalSeparator->addItem(i18nc("@item:inlistbox Stock", "Comma (,)"), AlkOnlineQuoteSource::DecimalSeparator::Comma);
+#endif
     connect(m_editPriceDecimalSeparator, SIGNAL(currentIndexChanged(int)), this, SLOT(slotEntryChanged()));
     connect(m_editPrice, SIGNAL(textChanged(QString)), this, SLOT(slotEntryChanged()));
 
@@ -267,6 +282,19 @@ AlkOnlineQuotesWidget::Private::Private(bool showProfiles, bool showUpload, AlkO
     connect(m_ghnsSource, SIGNAL(toggled(bool)), this, SLOT(slotEntryChanged()));
     connect(m_showButton, SIGNAL(clicked()), this, SLOT(slotShowButton()));
 
+    m_returnLastPriceStateComboBox->addItem(i18nc("@item:inlistbox Stock", "Off"), AlkOnlineQuote::LastPriceState::Off);
+    m_returnLastPriceStateComboBox->addItem(i18nc("@item:inlistbox Stock", "Always"), AlkOnlineQuote::LastPriceState::Always);
+    m_returnLastPriceStateComboBox->addItem(i18nc("@item:inlistbox Stock", "Always when today"), AlkOnlineQuote::LastPriceState::AlwaysWhenToday);
+    m_returnLastPriceStateComboBox->setData<AlkOnlineQuote::LastPriceState>(m_quote.returnLastPriceState());
+
+    connect(&m_quote, SIGNAL(status(QString)), this, SLOT(slotLogStatus(QString)));
+    connect(&m_quote, SIGNAL(error(QString)), this, SLOT(slotLogError(QString)));
+    connect(&m_quote, SIGNAL(failed(QString, QString)), this, SLOT(slotLogFailed(QString, QString)));
+    connect(&m_quote, SIGNAL(quote(QString, QString, QDate, double)), this, SLOT(slotLogQuote(QString, QString, QDate, double)));
+    connect(&m_quote, SIGNAL(quotes(QString, QString, AlkDatePriceMap)), this, SLOT(slotLogQuotes(QString, QString, AlkDatePriceMap)));
+
+    m_reverseSearchStateCheckBox->setChecked(m_quote.enableReverseLaunch());
+
     m_uploadButton->setVisible(false);
     m_acceptButton->setEnabled(false);
     m_resetButton->setVisible(m_showProfiles);
@@ -275,7 +303,10 @@ AlkOnlineQuotesWidget::Private::Private(bool showProfiles, bool showUpload, AlkO
 
 AlkOnlineQuotesWidget::Private::~Private()
 {
-    m_webPageDialog->deleteLater();
+    // only call deleteLater if we have created the dialog
+    if (m_webPageDialog) {
+        m_webPageDialog->deleteLater();
+    }
     delete m_webView->webPage();
     delete m_webView;
     delete m_model;
@@ -415,14 +446,14 @@ void AlkOnlineQuotesWidget::Private::slotLoadQuoteSource(const QModelIndex &inde
             source = source.asReference();
         m_editURL->setText(source.url());
         m_editIdentifier->setText(source.idRegex());
-        m_editIdSelector->setCurrentIndex(source.idSelector());
-        m_editPriceDecimalSeparator->setCurrentIndex(source.priceDecimalSeparator());
+        m_editIdSelector->setData<AlkOnlineQuoteSource::IdSelector>(source.idSelector());
+        m_editPriceDecimalSeparator->setData<AlkOnlineQuoteSource::DecimalSeparator>(source.priceDecimalSeparator());
         m_editPrice->setText(source.priceRegex());
-        m_editDataFormat->setCurrentIndex(m_editDataFormat->findData(source.dataFormat()));
+        m_editDataFormat->setData<AlkOnlineQuoteSource::DataFormat>(source.dataFormat());
         m_editDate->setText(source.dateRegex());
         m_editDateFormat->setText(source.dateFormat());
         m_editDefaultId->setText(source.defaultId());
-        m_editDownloadType->setCurrentIndex(source.downloadType());
+        m_editDownloadType->setData<AlkOnlineQuoteSource::DownloadType>(source.downloadType());
         m_ghnsSource->setChecked(source.isGHNS());
     }
 
@@ -481,13 +512,13 @@ void AlkOnlineQuotesWidget::Private::updateButtonState()
     bool modified = !m_currentItem.isReference() &&
                     (m_editURL->text() != m_currentItem.url()
                     || m_editIdentifier->text() != m_currentItem.idRegex()
-                    || m_editIdSelector->currentIndex() != static_cast<int>(m_currentItem.idSelector())
+                    || m_editIdSelector->currentIndex() != m_editIdSelector->findData(m_currentItem.idSelector())
                     || m_editDataFormat->currentIndex() != m_editDataFormat->findData(m_currentItem.dataFormat())
                     || m_editDate->text() != m_currentItem.dateRegex()
                     || m_editDateFormat->text() != m_currentItem.dateFormat()
                     || m_editDefaultId->text() != m_currentItem.defaultId()
-                    || m_editPriceDecimalSeparator->currentIndex() != static_cast<int>(m_currentItem.priceDecimalSeparator())
-                    || m_editDownloadType->currentIndex() != static_cast<int>(m_currentItem.downloadType())
+                    || m_editPriceDecimalSeparator->currentIndex() != m_editPriceDecimalSeparator->findData(m_currentItem.priceDecimalSeparator())
+                    || m_editDownloadType->currentIndex() != m_editDownloadType->findData(m_currentItem.downloadType())
                     || m_editPrice->text() != m_currentItem.priceRegex()
                     || m_ghnsSource->isChecked() != m_currentItem.isGHNS());
 
@@ -521,11 +552,13 @@ void AlkOnlineQuotesWidget::Private::updateButtonState()
         m_checkSymbol->setText(QString());
         m_checkSymbol2->setEnabled(true);
         setDefaultSource(m_checkSymbol2, source.defaultId(), "BTC GBP");
+        m_reverseSearchStateCheckBox->setVisible(true);
     } else {
         m_checkSymbol->setEnabled(true);
         setDefaultSource(m_checkSymbol, source.defaultId(), "ORCL");
         m_checkSymbol2->setEnabled(false);
         m_checkSymbol2->setText(QString());
+        m_reverseSearchStateCheckBox->setVisible(false);
     }
 }
 
@@ -553,6 +586,8 @@ void AlkOnlineQuotesWidget::Private::slotDeleteEntry()
 
     // keep this order to avoid deleting the wrong current item
     m_quoteSourceList->model()->removeRow(m_quoteSourceList->currentIndex().row());
+    // select next entry
+    slotLoadQuoteSource(m_quoteSourceList->currentIndex());
     updateButtonState();
 }
 
@@ -573,13 +608,13 @@ void AlkOnlineQuotesWidget::Private::slotAcceptEntry()
 {
     m_currentItem.setUrl(m_editURL->text());
     m_currentItem.setIdRegex(m_editIdentifier->text());
-    m_currentItem.setIdSelector(static_cast<AlkOnlineQuoteSource::IdSelector>(m_editIdSelector->currentIndex()));
+    m_currentItem.setIdSelector(m_editIdSelector->currentData().value<AlkOnlineQuoteSource::IdSelector>());
     m_currentItem.setDataFormat(m_editDataFormat->currentData().value<AlkOnlineQuoteSource::DataFormat>());
     m_currentItem.setDateRegex(m_editDate->text());
     m_currentItem.setDateFormat(m_editDateFormat->text());
     m_currentItem.setDefaultId(m_editDefaultId->text());
-    m_currentItem.setPriceDecimalSeparator(static_cast<AlkOnlineQuoteSource::DecimalSeparator>(m_editPriceDecimalSeparator->currentIndex()));
-    m_currentItem.setDownloadType(static_cast<AlkOnlineQuoteSource::DownloadType>(m_editDownloadType->currentIndex()));
+    m_currentItem.setPriceDecimalSeparator(m_editPriceDecimalSeparator->currentData().value<AlkOnlineQuoteSource::DecimalSeparator>());
+    m_currentItem.setDownloadType(m_editDownloadType->currentData().value<AlkOnlineQuoteSource::DownloadType>());
     m_currentItem.setPriceRegex(m_editPrice->text());
     m_currentItem.setGHNS(m_ghnsSource->isChecked());
     m_currentItem.write();
@@ -700,36 +735,30 @@ void AlkOnlineQuotesWidget::Private::setupIcons(const AlkOnlineQuote::Errors &er
 
 void AlkOnlineQuotesWidget::Private::slotCheckEntry()
 {
-    AlkOnlineQuote quote(m_profile);
+    m_quote.setProfile(m_profile);
     m_logWindow->setVisible(true);
     m_logWindow->clear();
     clearIcons();
-    quote.setAcceptLanguage(m_acceptLanguage);
-
-    connect(&quote, SIGNAL(status(QString)), this, SLOT(slotLogStatus(QString)));
-    connect(&quote, SIGNAL(error(QString)), this, SLOT(slotLogError(QString)));
-    connect(&quote, SIGNAL(failed(QString,QString)), this, SLOT(slotLogFailed(QString,QString)));
-    connect(&quote, SIGNAL(quote(QString,QString,QDate,double)), this,
-            SLOT(slotLogQuote(QString,QString,QDate,double)));
-    connect(&quote, SIGNAL(quotes(QString,QString,AlkDatePriceMap)), this,
-            SLOT(slotLogQuotes(QString,QString,AlkDatePriceMap)));
+    m_quote.setAcceptLanguage(m_acceptLanguage);
+    m_quote.setReturnLastPriceState(m_returnLastPriceStateComboBox->currentData().value<AlkOnlineQuote::LastPriceState>());
+    m_quote.setEnableReverseLaunch(m_reverseSearchStateCheckBox->checkState() == Qt::Checked);
     initIcons();
 
     AlkOnlineQuoteSource source(m_currentItem);
     if (source.isReference())
         source = source.asReference();
     if (source.dataFormat() == AlkOnlineQuoteSource::CSV || source.dataFormat() == AlkOnlineQuoteSource::JSON) {
-        quote.setDateRange(m_startDateEdit->date(), m_endDateEdit->date());
+        m_quote.setDateRange(m_startDateEdit->date(), m_endDateEdit->date());
     } else {
-        quote.setDateRange(QDate(), QDate());
+        m_quote.setDateRange(QDate(), QDate());
     }
-    quote.setReturnLastPriceState(static_cast<AlkOnlineQuote::LastPriceState>(m_returnLastPriceStateComboBox->currentIndex()));
+
     if (source.requiresTwoIdentifier()) {
-        quote.launch(m_checkSymbol2->text(), m_checkSymbol2->text(), source.name());
+        m_quote.launch(m_checkSymbol2->text(), m_checkSymbol2->text(), source.name());
     } else {
-        quote.launch(m_checkSymbol->text(), m_checkSymbol->text(), source.name());
+        m_quote.launch(m_checkSymbol->text(), m_checkSymbol->text(), source.name());
     }
-    setupIcons(quote.errors());
+    setupIcons(m_quote.errors());
 }
 
 void AlkOnlineQuotesWidget::Private::slotLogStatus(const QString &s)
