@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2018 Ralf Habacker ralf.habacker @freenet.de
+    SPDX-FileCopyrightText: 2018, 2024 Ralf Habacker ralf.habacker @freenet.de
 
     This file is part of libalkimia.
 
@@ -8,17 +8,30 @@
 
 #include "alkwebpage.h"
 
+#include "alkwebview.h"
+
 #if defined(BUILD_WITH_WEBENGINE)
+#include "../3rdparty/qtwebengine/tests/auto/util/util.h"
+
+#include <klocalizedstring.h>
+
+#include <QContextMenuEvent>
+#include <QDesktopServices>
 #include <QEventLoop>
-#include <QWebEnginePage>
-#include <QWebEngineView>
+#include <QMenu>
+#include <QPointer>
+#include <QTimer>
 #include <QUrl>
+#include <QWebEnginePage>
+#include <QWebEngineProfile>
+#include <QWebEngineView>
 
 class AlkWebPage::Private : public QObject
 {
     Q_OBJECT
 public:
     AlkWebPage *q;
+    int timeout{-1}; // msec
 
     explicit Private(AlkWebPage *_q)
         : q(_q)
@@ -26,23 +39,12 @@ public:
     }
     Private(const Private& right) = delete;
     Private& operator=(const Private& right) = delete;
-
-    void slotUrlChanged(const QUrl &url)
-    {
-        // This workaround is necessary because QWebEnginePage::urlChanged()
-        // returns the html content set with setContent() as url.
-        if (url.scheme().startsWith("http"))
-            Q_EMIT q->urlChanged(url);
-        else
-            Q_EMIT q->urlChanged(QUrl());
-    }
 };
 
 AlkWebPage::AlkWebPage(QWidget *parent)
   : QWebEnginePage(parent)
   , d(new Private(this))
 {
-    connect(this, &QWebEnginePage::urlChanged, d, &Private::slotUrlChanged);
 }
 
 AlkWebPage::~AlkWebPage()
@@ -50,41 +52,25 @@ AlkWebPage::~AlkWebPage()
     delete d;
 }
 
-QWidget *AlkWebPage::widget()
-{
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    if (!view())
-        setView(new QWebEngineView);
-    return view();
-#else
-    return QWebEngineView::forPage(this);
-#endif
-}
-
 void AlkWebPage::load(const QUrl &url, const QString &acceptLanguage)
 {
-    Q_UNUSED(acceptLanguage)
-
+    profile()->setHttpAcceptLanguage(acceptLanguage);
     setUrl(url);
 }
 
 QString AlkWebPage::toHtml()
 {
-    QString html;
-    QEventLoop loop;
-    QWebEnginePage::toHtml([&html, &loop](const QString &result)
-        {
-            html = result;
-            loop.quit();
-        }
-    );
-    loop.exec();
+    CallbackSpy<QString> spy;
+    QWebEnginePage::toHtml(spy.ref());
+    QString html = d->timeout != -1 ? spy.waitForResult(d->timeout) : spy.waitForResult();
     return html;
 }
 
-void AlkWebPage::setContent(const QString &s)
+QStringList AlkWebPage::getAllElements(const QString &symbol)
 {
-    setHtml(s);
+    Q_UNUSED(symbol)
+
+    return QStringList();
 }
 
 QString AlkWebPage::getFirstElement(const QString &symbol)
@@ -94,14 +80,21 @@ QString AlkWebPage::getFirstElement(const QString &symbol)
     return QString();
 }
 
-void AlkWebPage::setWebInspectorEnabled(bool state)
+void AlkWebPage::setTimeout(int timeout)
 {
-    Q_UNUSED(state)
+    d->timeout = timeout;
 }
 
-bool AlkWebPage::webInspectorEnabled()
+int AlkWebPage::timeout()
 {
-    return false;
+    return d->timeout;
+}
+
+bool AlkWebPage::acceptNavigationRequest(const QUrl &url, QWebEnginePage::NavigationType type, bool isMainFrame)
+{
+    if (type == QWebEnginePage::NavigationTypeRedirect && isMainFrame)
+        Q_EMIT loadRedirectedTo(url);
+    return QWebEnginePage::acceptNavigationRequest(url, type, isMainFrame);
 }
 
 #include "alkwebpage.moc"
@@ -116,51 +109,32 @@ bool AlkWebPage::webInspectorEnabled()
 class AlkWebPage::Private
 {
 public:
-    QWebInspector *inspector;
     AlkWebPage *p;
     QNetworkAccessManager *networkAccessManager;
     explicit Private(AlkWebPage *parent)
-      : inspector(nullptr),
-        p(parent),
-        networkAccessManager(new QNetworkAccessManager)
+        : p(parent)
+        , networkAccessManager(new QNetworkAccessManager)
     {
 #if QT_VERSION >= QT_VERSION_CHECK(5,9,0)
         // see https://community.kde.org/Policies/API_to_Avoid#QNetworkAccessManager
         networkAccessManager->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
 #endif
-        p->page()->setNetworkAccessManager(networkAccessManager);
+        p->setNetworkAccessManager(networkAccessManager);
     }
 
     ~Private()
     {
-        p->page()->settings()->setAttribute(QWebSettings::DeveloperExtrasEnabled, false);
-        inspector->setPage(nullptr);
-        delete inspector;
         delete networkAccessManager;
     }
-
-    void setWebInspectorEnabled(bool enable)
-    {
-        p->page()->settings()->setAttribute(QWebSettings::DeveloperExtrasEnabled, enable);
-        if (enable && !inspector) {
-            inspector = new QWebInspector();
-            inspector->setPage(p->page());
-        }
-    }
-
-    bool webInspectorEnabled()
-    {
-        return p->page()->settings()->testAttribute(QWebSettings::DeveloperExtrasEnabled);
-    }
 };
 
-AlkWebPage::AlkWebPage(QWidget *parent)
-  : QWebView(parent)
+AlkWebPage::AlkWebPage(QObject *parent)
+  : QWebPage(parent)
   , d(new Private(this))
 {
-    page()->settings()->setAttribute(QWebSettings::JavaEnabled, false);
-    page()->settings()->setAttribute(QWebSettings::AutoLoadImages, false);
-    page()->settings()->setAttribute(QWebSettings::PluginsEnabled, false);
+    settings()->setAttribute(QWebSettings::JavaEnabled, false);
+    settings()->setAttribute(QWebSettings::AutoLoadImages, false);
+    settings()->setAttribute(QWebSettings::PluginsEnabled, false);
 }
 
 AlkWebPage::~AlkWebPage()
@@ -168,55 +142,62 @@ AlkWebPage::~AlkWebPage()
     delete d;
 }
 
-QWidget *AlkWebPage::widget()
-{
-    return this;
-}
-
 void AlkWebPage::load(const QUrl &url, const QString &acceptLanguage)
 {
     QNetworkRequest request;
     request.setUrl(url);
     if (!acceptLanguage.isEmpty())
         request.setRawHeader("Accept-Language", acceptLanguage.toLocal8Bit());
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     if (url.query().toLower().contains(QLatin1String("method=post"))) {
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
-        QWebView::load(request, QNetworkAccessManager::PostOperation, url.query().toUtf8());
+        mainFrame()->load(request, QNetworkAccessManager::PostOperation, url.query().toUtf8());
 #else
     if (url.hasQueryItem(QLatin1String("method")) && url.queryItemValue(QLatin1String("method")).toLower()== QLatin1String("post")) {
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
-        QWebView::load(request, QNetworkAccessManager::PostOperation);
+        mainFrame()->load(request, QNetworkAccessManager::PostOperation);
 #endif
     } else
-        QWebView::load(request);
+        mainFrame()->load(request);
+}
+
+void AlkWebPage::setHtml(const QString &data)
+{
+    // TODO baseurl
+    mainFrame()->setHtml(data);
 }
 
 QString AlkWebPage::toHtml()
 {
-    QWebFrame *frame = page()->mainFrame();
+    QWebFrame *frame = mainFrame();
     return frame->toHtml();
 }
 
+QStringList AlkWebPage::getAllElements(const QString &symbol)
+{
+    QStringList result;
+    QWebFrame *frame = mainFrame();
+    QWebElementCollection elements = frame->findAllElements(symbol);
+    for (const auto &e: elements) {
+        result.append(e.toPlainText());
+    }
+    return result;
+}
+
 QString AlkWebPage::getFirstElement(const QString &symbol)
 {
-    QWebFrame *frame = page()->mainFrame();
+    QWebFrame *frame = mainFrame();
     QWebElement element = frame->findFirstElement(symbol);
     return element.toPlainText();
 }
 
-void AlkWebPage::setWebInspectorEnabled(bool enable)
-{
-    d->setWebInspectorEnabled(enable);
-}
-
-bool AlkWebPage::webInspectorEnabled()
-{
-    return d->webInspectorEnabled();
-}
-
 #else
 
+#include <QEventLoop>
+#include <QNetworkAccessManager>
+#include <QNetworkReply>
+#include <QThread>
+
 class AlkWebPage::Private
 {
 public:
@@ -228,6 +209,7 @@ AlkWebPage::AlkWebPage(QWidget *parent)
 {
     setOpenExternalLinks(false);
     setOpenLinks(false);
+    connect(this, SIGNAL(sourceChanged(QUrl)), SIGNAL(loadRedirectedTo(QUrl)));
 }
 
 AlkWebPage::~AlkWebPage()
@@ -235,25 +217,27 @@ AlkWebPage::~AlkWebPage()
     delete d;
 }
 
-QWidget *AlkWebPage::widget()
-{
-    return this;
-}
-
 void AlkWebPage::load(const QUrl &url, const QString &acceptLanguage)
 {
-    Q_UNUSED(url)
     Q_UNUSED(acceptLanguage)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    setSource(url, QTextDocument::HtmlResource);
+#else
+    setSource(url);
+#endif
+    Q_EMIT loadStarted();
 }
 
 void AlkWebPage::setUrl(const QUrl &url)
 {
-    Q_UNUSED(url)
+    load(url, QString());
 }
 
-void AlkWebPage::setContent(const QString &s)
+QStringList AlkWebPage::getAllElements(const QString &symbol)
 {
-    setHtml(s);
+    Q_UNUSED(symbol)
+
+    return QStringList();
 }
 
 QString AlkWebPage::getFirstElement(const QString &symbol)
@@ -263,14 +247,25 @@ QString AlkWebPage::getFirstElement(const QString &symbol)
     return QString();
 }
 
-void AlkWebPage::setWebInspectorEnabled(bool enable)
+QVariant AlkWebPage::loadResource(int type, const QUrl &name)
 {
-    Q_UNUSED(enable)
-}
+    switch(type) {
+    case QTextDocument::HtmlResource:
+    case QTextDocument::StyleSheetResource:
+        QNetworkAccessManager networkManager;
+        QNetworkRequest request;
+        request.setUrl(name);
+        QNetworkReply* reply = networkManager.get(request);
+        QEventLoop loop;
+        connect(reply, SIGNAL(finished()), &loop, SLOT(quit()));
+        connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), &loop, SLOT(quit()));
+        loop.exec();
+        QString data = reply->readAll();
+        Q_EMIT loadFinished(true);
+        return data;
+    }
 
-bool AlkWebPage::webInspectorEnabled()
-{
-    return false;
+    return QVariant();
 }
 
 #endif
