@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2018 Ralf Habacker ralf.habacker @freenet.de
+    SPDX-FileCopyrightText: 2018, 2024 Ralf Habacker ralf.habacker @freenet.de
 
     This file is part of libalkimia.
 
@@ -19,6 +19,13 @@ class QUrl;
 
 #include <QWebEnginePage>
 
+/**
+ * The AlkWebPage class provides an object for loading
+ * web documents in order to offer functionality such
+ * as AlkWebView in a widgetless environment.
+ *
+ * @author Ralf Habacker ralf.habacker @freenet.de
+ */
 class ALK_EXPORT AlkWebPage : public QWebEnginePage
 {
     Q_OBJECT
@@ -26,45 +33,52 @@ public:
     explicit AlkWebPage(QWidget *parent = nullptr);
     virtual ~AlkWebPage();
 
-    QWidget *widget();
     void load(const QUrl &url, const QString &acceptLanguage);
     QString toHtml();
-    void setContent(const QString &s);
+    QStringList getAllElements(const QString &symbol);
     QString getFirstElement(const QString &symbol);
-    void setWebInspectorEnabled(bool state);
-    bool webInspectorEnabled();
+    /// Set timeout [ms] for AlkWebPage::toHtml()
+    void setTimeout(int timeout = -1);
+    int timeout();
 
 Q_SIGNALS:
-    void urlChanged(const QUrl &url);
+    void loadRedirectedTo(const QUrl &url);
 
 private:
     class Private;
     Private *d;
+
+    bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) override;
 };
 
 #elif defined(BUILD_WITH_WEBKIT)
 
-#include <QWebView>
+#include <QWebPage>
 
 /**
- * The AlkWebPage class provides an interface
- * to a browser component
- * It is used for fetching and showing web pages.
+ * The AlkWebPage class provides an object for loading
+ * web documents in order to offer functionality such
+ * as AlkWebView in a widgetless environment.
  *
  * @author Ralf Habacker ralf.habacker @freenet.de
  */
-class ALK_EXPORT AlkWebPage : public QWebView
+class ALK_EXPORT AlkWebPage : public QWebPage
 {
+    Q_OBJECT
 public:
-    explicit AlkWebPage(QWidget *parent = nullptr);
+    explicit AlkWebPage(QObject *parent = nullptr);
     virtual ~AlkWebPage();
 
-    QWidget *widget();
     void load(const QUrl &url, const QString &acceptLanguage);
+    void setHtml(const QString &data);
     QString toHtml();
+    QStringList getAllElements(const QString &symbol);
     QString getFirstElement(const QString &symbol);
-    void setWebInspectorEnabled(bool enable);
-    bool webInspectorEnabled();
+    void setTimeout(int timeout = -1) { Q_UNUSED(timeout) }
+    int timeout() { return -1; }
+
+Q_SIGNALS:
+    void loadRedirectedTo(const QUrl&);
 
 private:
     class Private;
@@ -76,9 +90,9 @@ private:
 #include <QTextBrowser>
 
 /**
- * The AlkWebPage class provides an interface
- * to a browser component with javascript support
- * It is used for fetching and showing web pages.
+ * The AlkWebPage class provides an object to load
+ * and view web documents to provide functionality
+ * like AlkWebView in a widget-less environment.
  *
  * @author Ralf Habacker ralf.habacker @freenet.de
  */
@@ -89,20 +103,22 @@ public:
     explicit AlkWebPage(QWidget *parent = nullptr);
     virtual ~AlkWebPage();
 
-    QWidget *widget();
     void load(const QUrl &url, const QString &acceptLanguage);
     void setUrl(const QUrl &url);
-    void setContent(const QString &s);
+    QStringList getAllElements(const QString &symbol);
     QString getFirstElement(const QString &symbol);
-    void setWebInspectorEnabled(bool enable);
-    bool webInspectorEnabled();
+    void setTimeout(int timeout = -1) { Q_UNUSED(timeout) }
+    int timeout() { return -1; }
+
 Q_SIGNALS:
     void loadStarted();
     void loadFinished(bool);
+    void loadRedirectedTo(const QUrl&);
 
 private:
     class Private;
     Private *d;
+    QVariant loadResource(int type, const QUrl &name) override;
 };
 #endif
 
