@@ -5,6 +5,9 @@
 #
 # SPDX-License-Identifier: MIT
 
+# add timestamps
+export PS4='[$(date "+%T.%3N")]'" $PS4"
+
 set -euo pipefail
 set -x
 
@@ -110,6 +113,9 @@ function init_docker() {
 print("loading gdb event handler")
 python
 
+# for pretty printer
+gdb.execute("set auto-load safe-path /")
+
 def stop_handler (event):
     print ("event type: stop")
     gdb.execute("set pagination off")
@@ -255,14 +261,14 @@ init_cross_runtime() {
 # See ci-install.sh
 : "${ci_host:=native}"
 
+# ci_parallel:
+# A number of parallel jobs, passed to make -j
+: "${ci_parallel:=1}"
+
 # ci_in_docker:
 # flags to indicate that we are running in docker
 : "${ci_in_docker:=auto}"
 
-# ci_jobs:
-# number of jobs
-: "${ci_jobs:=5}"
-
 # ci_runtime:
 # One of static, shared; used for windows cross builds
 : "${ci_runtime:=shared}"
@@ -279,6 +285,10 @@ init_cross_runtime() {
 # if yes, run simple webserver for testing
 : "${ci_webserver:=yes}"
 
+# ci_cmake_options:
+# empty if not set
+: "${ci_cmake_options:=}"
+
 # host name for testing
 test_host=dev.kmymoney.org
 
@@ -306,7 +316,7 @@ if [ "$ci_in_docker" = "yes" ] && [ -n `getent passwd | grep ^user` ]; then
 fi
 
 # common cmake options
-cmake_options="-DBUILD_WITH_QTNETWORK=1"
+cmake_options=$ci_cmake_options
 
 # check if webserver is enabled
 if [ "$ci_webserver" = yes ]; then
@@ -328,7 +338,7 @@ fi
 # settings for build variants
 case "$ci_variant" in
     (kf6*)
-        cmake_options+=" -DBUILD_APPLETS=0 -DBUILD_TESTING=1 -DENABLE_CLIENT_PACKAGE_TEST=1 -DBUILD_WITH_QT6=1 -DBUILD_WITH_QTNETWORK=1 -DCMAKE_CXX_COMPILER=g++-12"
+        cmake_options+=" -DBUILD_APPLETS=0 -DBUILD_TESTING=1 -DENABLE_CLIENT_PACKAGE_TEST=1 -DBUILD_WITH_QT6=1"
         cmake_suffix="kf6"
         export QT_LOGGING_RULES="*=true;kf.kio.workers.http.debug=false;qt.text.*.debug=false"
         export QT_FORCE_STDERR_LOGGING=1
@@ -378,7 +388,7 @@ case "$ci_host" in
 esac
 
 # custom settings
-cmake_options+=" -DBUILD_WITH_QTNETWORK=1 -DBUILD_WITH_KIO=1"
+cmake_options+=""
 case "$ci_variant" in
     (kf[56])
         cmake_options+=" -DBUILD_WITH_WEBKIT=0 -DBUILD_WITH_WEBENGINE=0"
@@ -406,7 +416,7 @@ fi
 # configure and build
 if test "$ci_build" = yes; then
     $cmake_configure -- -S ${srcdir} -B ${builddir} $cmake_options
-    $cmake --build ${builddir} -j$ci_jobs
+    $cmake --build ${builddir} -j$ci_parallel
 fi
 
 # run tests
@@ -419,7 +429,7 @@ if test "$ci_test" = yes; then
     start_webserver
 
     # run tests
-    ctest --test-dir ${builddir} --output-on-failure --timeout 60 --parallel $ci_jobs -VV
+    ctest --test-dir ${builddir} --timeout 60 --parallel $ci_parallel -VV
 
     # show screenshot in case of errors
     if test $? -ne 0; then
