@@ -9,8 +9,8 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#include <QMainWindow>
 #include "applicationsettings.h"
+#include <QMainWindow>
 
 class QUrl;
 
@@ -24,7 +24,7 @@ public:
 
 protected Q_SLOTS:
     void slotUpdateAvailable(const QString &profile, const QString &name);
-    void slotUrlChanged(const QUrl &url);
+    void slotLoadRedirectedTo(const QUrl &url);
     void slotEditingFinished();
     void slotLanguageChanged(const QString &);
 
